@@ -7,7 +7,6 @@ import clickclick
 import dateutil.parser
 import natsort
 from zalando_kubectl.models.bluegreen import BlueGreen
-from zalando_kubectl.models.ingresstemplate import IngressTemplate
 from zalando_kubectl.models.stackset import StackSet
 from zalando_kubectl.models.stackset_ingress_authoritative import StackSetIngressAuthoritative
 from zalando_kubectl.utils import ExternalBinary
@@ -35,10 +34,6 @@ def get_bluegreen(kubectl: ExternalBinary, name: str):
             res = kubectl_run(kubectl, "get", "Stacks", "-l", "stackset={}".format(name), "-o", "json")
             return StackSetIngressAuthoritative(ingress_def, json.loads(res))
 
-        # IngressTemplate
-        elif ref["kind"] == "IngressTemplate":
-            return IngressTemplate(ingress_def)
-
 
 def print_traffic(kubectl: ExternalBinary, bluegreen: BlueGreen, timeout=0):
     """Print the stacks and their weights in table format."""
